==> SingleRBook_1.2.0.tar.gz: SingleRBook/vignettes/book/docs/pancreas.md <==
---
bibliography: ref.bib
---

# (PART) Case studies {-}

# Cross-annotating human pancreas {#pancreas-case-study}

<script>
document.addEventListener("click", function (event) {
    if (event.target.classList.contains("rebook-collapse")) {
        event.target.classList.toggle("active");
        var content = event.target.nextElementSibling;
        if (content.style.display === "block") {
            content.style.display = "none";
        } else {
            content.style.display = "block";
        }
    }
})
</script>

<style>
.rebook-collapse {
  background-color: #eee;
  color: #444;
  cursor: pointer;
  padding: 18px;
  width: 100%;
  border: none;
  text-align: left;
  outline: none;
  font-size: 15px;
}

.rebook-content {
  padding: 0 18px;
  display: none;
  overflow: hidden;
  background-color: #f1f1f1;
}
</style>

## Loading the data

We load the @muraro2016singlecell dataset as our reference, removing unlabelled cells or cells without a clear label.


```r
library(scRNAseq)
sceM <- MuraroPancreasData()
sceM <- sceM[,!is.na(sceM$label) & sceM$label!="unclear"] 
```

We compute log-expression values for use in marker detection inside `SingleR()`.


```r
library(scater)
sceM <- logNormCounts(sceM)
```

We examine the distribution of labels in this reference.


```r
table(sceM$label)
```

```
## 
##      acinar       alpha        beta       delta        duct endothelial 
##         219         812         448         193         245          21 
##     epsilon mesenchymal          pp 
##           3          80         101
```

We load the @grun2016denovo dataset as our test,
applying some basic quality control to remove low-quality cells in some of the batches
(see [here](https://osca.bioconductor.org/grun-human-pancreas-cel-seq2.html#quality-control-8) for details).


```r
sceG <- GrunPancreasData()

sceG <- addPerCellQC(sceG)
qc <- quickPerCellQC(colData(sceG), 
    percent_subsets="altexps_ERCC_percent",
    batch=sceG$donor,
    subset=sceG$donor %in% c("D17", "D7", "D2"))
sceG <- sceG[,!qc$discard]
```

Technically speaking, the test dataset does not need log-expression values but we compute them anyway for convenience.


```r
sceG <- logNormCounts(sceG)
```

## Applying the annotation

We apply `SingleR()` with Wilcoxon rank sum test-based marker detection to annotate the Grun dataset with the Muraro labels.


```r
library(SingleR)
pred.grun <- SingleR(test=sceG, ref=sceM, labels=sceM$label, de.method="wilcox")
```

We examine the distribution of predicted labels:


```r
table(pred.grun$labels)
```

```
## 
##      acinar       alpha        beta       delta        duct endothelial 
##         277         203         181          50         306           5 
##     epsilon mesenchymal          pp 
##           1          22          19
```

We can also examine the number of discarded cells for each label:


```r
table(Label=pred.grun$labels,
    Lost=is.na(pred.grun$pruned.labels))
```

```
##              Lost
## Label         FALSE TRUE
##   acinar        251   26
##   alpha         198    5
##   beta          180    1
##   delta          49    1
##   duct          301    5
##   endothelial     4    1
##   epsilon         1    0
##   mesenchymal    22    0
##   pp             17    2
```

## Diagnostics

We visualize the assignment scores for each label in Figure \@ref(fig:unref-pancreas-score-heatmap).


```r
plotScoreHeatmap(pred.grun)
```

<div class="figure">
<img src="pancreas_files/figure-html/unref-pancreas-score-heatmap-1.png" alt="Heatmap of the (normalized) assignment scores for each cell (column) in the Grun test dataset with respect to each label (row) in the Muraro reference dataset. The final assignment for each cell is shown in the annotation bar at the top." width="672" />
<p class="caption">(\#fig:unref-pancreas-score-heatmap)Heatmap of the (normalized) assignment scores for each cell (column) in the Grun test dataset with respect to each label (row) in the Muraro reference dataset. The final assignment for each cell is shown in the annotation bar at the top.</p>
</div>

The delta for each cell is visualized in Figure \@ref(fig:unref-pancreas-delta-dist).


```r
plotDeltaDistribution(pred.grun)
```

<div class="figure">
<img src="pancreas_files/figure-html/unref-pancreas-delta-dist-1.png" alt="Distributions of the deltas for each cell in the Grun dataset assigned to each label in the Muraro dataset. Each cell is represented by a point; low-quality assignments that were pruned out are colored in orange." width="672" />
<p class="caption">(\#fig:unref-pancreas-delta-dist)Distributions of the deltas for each cell in the Grun dataset assigned to each label in the Muraro dataset. Each cell is represented by a point; low-quality assignments that were pruned out are colored in orange.</p>
</div>

Finally, we visualize the heatmaps of the marker genes for each label in Figure \@ref(fig:unref-pancreas-marker-heat).


```r
library(scater)
collected <- list()
all.markers <- metadata(pred.grun)$de.genes

sceG$labels <- pred.grun$labels
for (lab in unique(pred.grun$labels)) {
    collected[[lab]] <- plotHeatmap(sceG, silent=TRUE, 
        order_columns_by="labels", main=lab,
        features=unique(unlist(all.markers[[lab]])))[[4]] 
}
do.call(gridExtra::grid.arrange, collected)
```

<div class="figure">
<img src="pancreas_files/figure-html/unref-pancreas-marker-heat-1.png" alt="Heatmaps of log-expression values in the Grun dataset for all marker genes upregulated in each label in the Muraro reference dataset. Assigned labels for each cell are shown at the top of each plot." width="1920" />
<p class="caption">(\#fig:unref-pancreas-marker-heat)Heatmaps of log-expression values in the Grun dataset for all marker genes upregulated in each label in the Muraro reference dataset. Assigned labels for each cell are shown at the top of each plot.</p>
</div>

## Comparison to clusters

For comparison, we will perform a quick unsupervised analysis of the Grun dataset.
We model the variances using the spike-in data and we perform graph-based clustering
(increasing the resolution by dropping `k=5`).


```r
library(scran)
decG <- modelGeneVarWithSpikes(sceG, "ERCC")

set.seed(1000100)
sceG <- denoisePCA(sceG, decG)

library(bluster)
sceG$cluster <- clusterRows(reducedDim(sceG), NNGraphParam(k=5))
```

We see that the clusters map reasonably well to the labels in Figure \@ref(fig:unref-pancreas-label-clusters).


```r
tab <- table(cluster=sceG$cluster, label=pred.grun$labels) 
pheatmap::pheatmap(log10(tab+10))
```

<div class="figure">
<img src="pancreas_files/figure-html/unref-pancreas-label-clusters-1.png" alt="Heatmap of the log-transformed number of cells in each combination of label (column) and cluster (row) in the Grun dataset." width="672" />
<p class="caption">(\#fig:unref-pancreas-label-clusters)Heatmap of the log-transformed number of cells in each combination of label (column) and cluster (row) in the Grun dataset.</p>
</div>



We proceed to the most important part of the analysis.
Yes, that's right, the $t$-SNE plot (Figure \@ref(fig:unref-pancreas-label-tsne)).


```r
set.seed(101010100)
sceG <- runTSNE(sceG, dimred="PCA")
plotTSNE(sceG, colour_by="cluster", text_colour="red",
    text_by=I(pred.grun$labels))
```

<div class="figure">
<img src="pancreas_files/figure-html/unref-pancreas-label-tsne-1.png" alt="$t$-SNE plot of the Grun dataset, where each point is a cell and is colored by the assigned cluster. Reference labels from the Muraro dataset are also placed on the median coordinate across all cells assigned with that label." width="672" />
<p class="caption">(\#fig:unref-pancreas-label-tsne)$t$-SNE plot of the Grun dataset, where each point is a cell and is colored by the assigned cluster. Reference labels from the Muraro dataset are also placed on the median coordinate across all cells assigned with that label.</p>
</div>

## Session information {-}

<button class="rebook-collapse">View session info</button>
<div class="rebook-content">
```
R version 4.1.0 (2021-05-18)
Platform: x86_64-pc-linux-gnu (64-bit)
Running under: Ubuntu 20.04.2 LTS

Matrix products: default
BLAS:   /home/biocbuild/bbs-3.13-bioc/R/lib/libRblas.so
LAPACK: /home/biocbuild/bbs-3.13-bioc/R/lib/libRlapack.so

locale:
 [1] LC_CTYPE=en_US.UTF-8       LC_NUMERIC=C              
 [3] LC_TIME=en_US.UTF-8        LC_COLLATE=C              
 [5] LC_MONETARY=en_US.UTF-8    LC_MESSAGES=en_US.UTF-8   
 [7] LC_PAPER=en_US.UTF-8       LC_NAME=C                 
 [9] LC_ADDRESS=C               LC_TELEPHONE=C            
[11] LC_MEASUREMENT=en_US.UTF-8 LC_IDENTIFICATION=C       

attached base packages:
[1] parallel  stats4    stats     graphics  grDevices utils     datasets 
[8] methods   base     

other attached packages:
 [1] bluster_1.2.0               scran_1.20.0               
 [3] SingleR_1.6.1               scater_1.20.0              
 [5] ggplot2_3.3.3               scuttle_1.2.0              
 [7] scRNAseq_2.6.0              SingleCellExperiment_1.14.1
 [9] SummarizedExperiment_1.22.0 Biobase_2.52.0             
[11] GenomicRanges_1.44.0        GenomeInfoDb_1.28.0        
[13] IRanges_2.26.0              S4Vectors_0.30.0           
[15] BiocGenerics_0.38.0         MatrixGenerics_1.4.0       
[17] matrixStats_0.58.0          BiocStyle_2.20.0           
[19] rebook_1.2.0               

loaded via a namespace (and not attached):
  [1] AnnotationHub_3.0.0           BiocFileCache_2.0.0          
  [3] igraph_1.2.6                  lazyeval_0.2.2               
  [5] BiocParallel_1.26.0           digest_0.6.27                
  [7] ensembldb_2.16.0              htmltools_0.5.1.1            
  [9] viridis_0.6.1                 fansi_0.4.2                  
 [11] magrittr_2.0.1                memoise_2.0.0                
 [13] ScaledMatrix_1.0.0            cluster_2.1.2                
 [15] limma_3.48.0                  Biostrings_2.60.0            
 [17] prettyunits_1.1.1             colorspace_2.0-1             
 [19] blob_1.2.1                    rappdirs_0.3.3               
 [21] xfun_0.23                     dplyr_1.0.6                  
 [23] crayon_1.4.1                  RCurl_1.98-1.3               
 [25] jsonlite_1.7.2                graph_1.70.0                 
 [27] glue_1.4.2                    gtable_0.3.0                 
 [29] zlibbioc_1.38.0               XVector_0.32.0               
 [31] DelayedArray_0.18.0           BiocSingular_1.8.0           
 [33] scales_1.1.1                  pheatmap_1.0.12              
 [35] edgeR_3.34.0                  DBI_1.1.1                    
 [37] Rcpp_1.0.6                    viridisLite_0.4.0            
 [39] xtable_1.8-4                  progress_1.2.2               
 [41] dqrng_0.3.0                   bit_4.0.4                    
 [43] rsvd_1.0.5                    metapod_1.0.0                
 [45] httr_1.4.2                    RColorBrewer_1.1-2           
 [47] dir.expiry_1.0.0              ellipsis_0.3.2               
 [49] farver_2.1.0                  pkgconfig_2.0.3              
 [51] XML_3.99-0.6                  CodeDepends_0.6.5            
 [53] sass_0.4.0                    dbplyr_2.1.1                 
 [55] locfit_1.5-9.4                utf8_1.2.1                   
 [57] labeling_0.4.2                tidyselect_1.1.1             
 [59] rlang_0.4.11                  later_1.2.0                  
 [61] AnnotationDbi_1.54.0          munsell_0.5.0                
 [63] BiocVersion_3.13.1            tools_4.1.0                  
 [65] cachem_1.0.5                  generics_0.1.0               
 [67] RSQLite_2.2.7                 ExperimentHub_2.0.0          
 [69] evaluate_0.14                 stringr_1.4.0                
 [71] fastmap_1.1.0                 yaml_2.2.1                   
 [73] knitr_1.33                    bit64_4.0.5                  
 [75] purrr_0.3.4                   KEGGREST_1.32.0              
 [77] AnnotationFilter_1.16.0       sparseMatrixStats_1.4.0      
 [79] mime_0.10                     biomaRt_2.48.0               
 [81] compiler_4.1.0                beeswarm_0.3.1               
 [83] filelock_1.0.2                curl_4.3.1                   
 [85] png_0.1-7                     interactiveDisplayBase_1.30.0
 [87] statmod_1.4.36                tibble_3.1.2                 
 [89] bslib_0.2.5.1                 stringi_1.6.2                
 [91] highr_0.9                     GenomicFeatures_1.44.0       
 [93] lattice_0.20-44               ProtGenerics_1.24.0          
 [95] Matrix_1.3-3                  vctrs_0.3.8                  
 [97] pillar_1.6.1                  lifecycle_1.0.0              
 [99] BiocManager_1.30.15           jquerylib_0.1.4              
[101] BiocNeighbors_1.10.0          cowplot_1.1.1                
[103] bitops_1.0-7                  irlba_2.3.3                  
[105] httpuv_1.6.1                  rtracklayer_1.52.0           
[107] R6_2.5.0                      BiocIO_1.2.0                 
[109] bookdown_0.22                 promises_1.2.0.1             
[111] gridExtra_2.3                 vipor_0.4.5                  
[113] codetools_0.2-18              assertthat_0.2.1             
[115] rjson_0.2.20                  withr_2.4.2                  
[117] GenomicAlignments_1.28.0      Rsamtools_2.8.0              
[119] GenomeInfoDbData_1.2.6        hms_1.1.0                    
[121] grid_4.1.0                    beachmat_2.8.0               
[123] rmarkdown_2.8                 DelayedMatrixStats_1.14.0    
[125] Rtsne_0.15                    shiny_1.6.0                  
[127] ggbeeswarm_0.6.0              restfulr_0.0.13              
```
</div>

==> SingleRBook_1.4.0.tar.gz: SingleRBook/vignettes/book/docs/pancreas.md <==
---
bibliography: ref.bib
---

# (PART) Case studies {-}

# Cross-annotating human pancreas {#pancreas-case-study}

<script>
document.addEventListener("click", function (event) {
    if (event.target.classList.contains("rebook-collapse")) {
        event.target.classList.toggle("active");
        var content = event.target.nextElementSibling;
        if (content.style.display === "block") {
            content.style.display = "none";
        } else {
            content.style.display = "block";
        }
    }
})
</script>

<style>
.rebook-collapse {
  background-color: #eee;
  color: #444;
  cursor: pointer;
  padding: 18px;
  width: 100%;
  border: none;
  text-align: left;
  outline: none;
  font-size: 15px;
}

.rebook-content {
  padding: 0 18px;
  display: none;
  overflow: hidden;
  background-color: #f1f1f1;
}
</style>

## Loading the data

We load the @muraro2016singlecell dataset as our reference, removing unlabelled cells or cells without a clear label.


```r
library(scRNAseq)
sceM <- MuraroPancreasData()
sceM <- sceM[,!is.na(sceM$label) & sceM$label!="unclear"] 
```

We compute log-expression values for use in marker detection inside `SingleR()`.


```r
library(scater)
sceM <- logNormCounts(sceM)
```

We examine the distribution of labels in this reference.


```r
table(sceM$label)
```

```
## 
##      acinar       alpha        beta       delta        duct endothelial 
##         219         812         448         193         245          21 
##     epsilon mesenchymal          pp 
##           3          80         101
```

We load the @grun2016denovo dataset as our test,
applying some basic quality control to remove low-quality cells in some of the batches
(see [here](https://osca.bioconductor.org/grun-human-pancreas-cel-seq2.html#quality-control-8) for details).


```r
sceG <- GrunPancreasData()

sceG <- addPerCellQC(sceG)
qc <- quickPerCellQC(colData(sceG), 
    percent_subsets="altexps_ERCC_percent",
    batch=sceG$donor,
    subset=sceG$donor %in% c("D17", "D7", "D2"))
sceG <- sceG[,!qc$discard]
```

Technically speaking, the test dataset does not need log-expression values but we compute them anyway for convenience.


```r
sceG <- logNormCounts(sceG)
```

## Applying the annotation

We apply `SingleR()` with Wilcoxon rank sum test-based marker detection to annotate the Grun dataset with the Muraro labels.


```r
library(SingleR)
pred.grun <- SingleR(test=sceG, ref=sceM, labels=sceM$label, de.method="wilcox")
```

We examine the distribution of predicted labels:


```r
table(pred.grun$labels)
```

```
## 
##      acinar       alpha        beta       delta        duct endothelial 
##         277         203         181          50         306           5 
##     epsilon mesenchymal          pp 
##           1          22          19
```

We can also examine the number of discarded cells for each label:


```r
table(Label=pred.grun$labels,
    Lost=is.na(pred.grun$pruned.labels))
```

```
##              Lost
## Label         FALSE TRUE
##   acinar        251   26
##   alpha         198    5
##   beta          180    1
##   delta          49    1
##   duct          301    5
##   endothelial     4    1
##   epsilon         1    0
##   mesenchymal    22    0
##   pp             17    2
```

## Diagnostics

We visualize the assignment scores for each label in Figure \@ref(fig:unref-pancreas-score-heatmap).


```r
plotScoreHeatmap(pred.grun)
```

<div class="figure">
<img src="pancreas_files/figure-html/unref-pancreas-score-heatmap-1.png" alt="Heatmap of the (normalized) assignment scores for each cell (column) in the Grun test dataset with respect to each label (row) in the Muraro reference dataset. The final assignment for each cell is shown in the annotation bar at the top." width="672" />
<p class="caption">(\#fig:unref-pancreas-score-heatmap)Heatmap of the (normalized) assignment scores for each cell (column) in the Grun test dataset with respect to each label (row) in the Muraro reference dataset. The final assignment for each cell is shown in the annotation bar at the top.</p>
</div>

The delta for each cell is visualized in Figure \@ref(fig:unref-pancreas-delta-dist).


```r
plotDeltaDistribution(pred.grun)
```

<div class="figure">
<img src="pancreas_files/figure-html/unref-pancreas-delta-dist-1.png" alt="Distributions of the deltas for each cell in the Grun dataset assigned to each label in the Muraro dataset. Each cell is represented by a point; low-quality assignments that were pruned out are colored in orange." width="672" />
<p class="caption">(\#fig:unref-pancreas-delta-dist)Distributions of the deltas for each cell in the Grun dataset assigned to each label in the Muraro dataset. Each cell is represented by a point; low-quality assignments that were pruned out are colored in orange.</p>
</div>

Finally, we visualize the heatmaps of the marker genes for each label in Figure \@ref(fig:unref-pancreas-marker-heat).


```r
library(scater)
collected <- list()
all.markers <- metadata(pred.grun)$de.genes

sceG$labels <- pred.grun$labels
for (lab in unique(pred.grun$labels)) {
    collected[[lab]] <- plotHeatmap(sceG, silent=TRUE, 
        order_columns_by="labels", main=lab,
        features=unique(unlist(all.markers[[lab]])))[[4]] 
}
do.call(gridExtra::grid.arrange, collected)
```

<div class="figure">
<img src="pancreas_files/figure-html/unref-pancreas-marker-heat-1.png" alt="Heatmaps of log-expression values in the Grun dataset for all marker genes upregulated in each label in the Muraro reference dataset. Assigned labels for each cell are shown at the top of each plot." width="1920" />
<p class="caption">(\#fig:unref-pancreas-marker-heat)Heatmaps of log-expression values in the Grun dataset for all marker genes upregulated in each label in the Muraro reference dataset. Assigned labels for each cell are shown at the top of each plot.</p>
</div>

## Comparison to clusters

For comparison, we will perform a quick unsupervised analysis of the Grun dataset.
We model the variances using the spike-in data and we perform graph-based clustering
(increasing the resolution by dropping `k=5`).


```r
library(scran)
decG <- modelGeneVarWithSpikes(sceG, "ERCC")

set.seed(1000100)
sceG <- denoisePCA(sceG, decG)

library(bluster)
sceG$cluster <- clusterRows(reducedDim(sceG), NNGraphParam(k=5))
```

We see that the clusters map reasonably well to the labels in Figure \@ref(fig:unref-pancreas-label-clusters).


```r
tab <- table(cluster=sceG$cluster, label=pred.grun$labels) 
pheatmap::pheatmap(log10(tab+10))
```

<div class="figure">
<img src="pancreas_files/figure-html/unref-pancreas-label-clusters-1.png" alt="Heatmap of the log-transformed number of cells in each combination of label (column) and cluster (row) in the Grun dataset." width="672" />
<p class="caption">(\#fig:unref-pancreas-label-clusters)Heatmap of the log-transformed number of cells in each combination of label (column) and cluster (row) in the Grun dataset.</p>
</div>



We proceed to the most important part of the analysis.
Yes, that's right, the $t$-SNE plot (Figure \@ref(fig:unref-pancreas-label-tsne)).


```r
set.seed(101010100)
sceG <- runTSNE(sceG, dimred="PCA")
plotTSNE(sceG, colour_by="cluster", text_colour="red",
    text_by=I(pred.grun$labels))
```

<div class="figure">
<img src="pancreas_files/figure-html/unref-pancreas-label-tsne-1.png" alt="$t$-SNE plot of the Grun dataset, where each point is a cell and is colored by the assigned cluster. Reference labels from the Muraro dataset are also placed on the median coordinate across all cells assigned with that label." width="672" />
<p class="caption">(\#fig:unref-pancreas-label-tsne)$t$-SNE plot of the Grun dataset, where each point is a cell and is colored by the assigned cluster. Reference labels from the Muraro dataset are also placed on the median coordinate across all cells assigned with that label.</p>
</div>

## Session information {-}

<button class="rebook-collapse">View session info</button>
<div class="rebook-content">
```
R version 4.1.1 (2021-08-10)
Platform: x86_64-pc-linux-gnu (64-bit)
Running under: Ubuntu 20.04.3 LTS

Matrix products: default
BLAS:   /home/biocbuild/bbs-3.14-bioc/R/lib/libRblas.so
LAPACK: /home/biocbuild/bbs-3.14-bioc/R/lib/libRlapack.so

locale:
 [1] LC_CTYPE=en_US.UTF-8       LC_NUMERIC=C              
 [3] LC_TIME=en_GB              LC_COLLATE=C              
 [5] LC_MONETARY=en_US.UTF-8    LC_MESSAGES=en_US.UTF-8   
 [7] LC_PAPER=en_US.UTF-8       LC_NAME=C                 
 [9] LC_ADDRESS=C               LC_TELEPHONE=C            
[11] LC_MEASUREMENT=en_US.UTF-8 LC_IDENTIFICATION=C       

attached base packages:
[1] stats4    stats     graphics  grDevices utils     datasets  methods  
[8] base     

other attached packages:
 [1] bluster_1.4.0               scran_1.22.0               
 [3] SingleR_1.8.0               scater_1.22.0              
 [5] ggplot2_3.3.5               scuttle_1.4.0              
 [7] scRNAseq_2.7.2              SingleCellExperiment_1.16.0
 [9] SummarizedExperiment_1.24.0 Biobase_2.54.0             
[11] GenomicRanges_1.46.0        GenomeInfoDb_1.30.0        
[13] IRanges_2.28.0              S4Vectors_0.32.0           
[15] BiocGenerics_0.40.0         MatrixGenerics_1.6.0       
[17] matrixStats_0.61.0          BiocStyle_2.22.0           
[19] rebook_1.4.0               

loaded via a namespace (and not attached):
  [1] AnnotationHub_3.2.0           BiocFileCache_2.2.0          
  [3] igraph_1.2.7                  lazyeval_0.2.2               
  [5] BiocParallel_1.28.0           digest_0.6.28                
  [7] ensembldb_2.18.0              htmltools_0.5.2              
  [9] viridis_0.6.2                 fansi_0.5.0                  
 [11] magrittr_2.0.1                memoise_2.0.0                
 [13] ScaledMatrix_1.2.0            cluster_2.1.2                
 [15] limma_3.50.0                  Biostrings_2.62.0            
 [17] prettyunits_1.1.1             colorspace_2.0-2             
 [19] blob_1.2.2                    rappdirs_0.3.3               
 [21] ggrepel_0.9.1                 xfun_0.27                    
 [23] dplyr_1.0.7                   crayon_1.4.1                 
 [25] RCurl_1.98-1.5                jsonlite_1.7.2               
 [27] graph_1.72.0                  glue_1.4.2                   
 [29] gtable_0.3.0                  zlibbioc_1.40.0              
 [31] XVector_0.34.0                DelayedArray_0.20.0          
 [33] BiocSingular_1.10.0           scales_1.1.1                 
 [35] pheatmap_1.0.12               edgeR_3.36.0                 
 [37] DBI_1.1.1                     Rcpp_1.0.7                   
 [39] viridisLite_0.4.0             xtable_1.8-4                 
 [41] progress_1.2.2                dqrng_0.3.0                  
 [43] bit_4.0.4                     rsvd_1.0.5                   
 [45] metapod_1.2.0                 httr_1.4.2                   
 [47] RColorBrewer_1.1-2            dir.expiry_1.2.0             
 [49] ellipsis_0.3.2                farver_2.1.0                 
 [51] pkgconfig_2.0.3               XML_3.99-0.8                 
 [53] CodeDepends_0.6.5             sass_0.4.0                   
 [55] dbplyr_2.1.1                  locfit_1.5-9.4               
 [57] utf8_1.2.2                    labeling_0.4.2               
 [59] tidyselect_1.1.1              rlang_0.4.12                 
 [61] later_1.3.0                   AnnotationDbi_1.56.0         
 [63] munsell_0.5.0                 BiocVersion_3.14.0           
 [65] tools_4.1.1                   cachem_1.0.6                 
 [67] generics_0.1.1                RSQLite_2.2.8                
 [69] ExperimentHub_2.2.0           evaluate_0.14                
 [71] stringr_1.4.0                 fastmap_1.1.0                
 [73] yaml_2.2.1                    knitr_1.36                   
 [75] bit64_4.0.5                   purrr_0.3.4                  
 [77] KEGGREST_1.34.0               AnnotationFilter_1.18.0      
 [79] sparseMatrixStats_1.6.0       mime_0.12                    
 [81] xml2_1.3.2                    biomaRt_2.50.0               
 [83] compiler_4.1.1                beeswarm_0.4.0               
 [85] filelock_1.0.2                curl_4.3.2                   
 [87] png_0.1-7                     interactiveDisplayBase_1.32.0
 [89] statmod_1.4.36                tibble_3.1.5                 
 [91] bslib_0.3.1                   stringi_1.7.5                
 [93] highr_0.9                     GenomicFeatures_1.46.0       
 [95] lattice_0.20-45               ProtGenerics_1.26.0          
 [97] Matrix_1.3-4                  vctrs_0.3.8                  
 [99] pillar_1.6.4                  lifecycle_1.0.1              
[101] BiocManager_1.30.16           jquerylib_0.1.4              
[103] BiocNeighbors_1.12.0          cowplot_1.1.1                
[105] bitops_1.0-7                  irlba_2.3.3                  
[107] httpuv_1.6.3                  rtracklayer_1.54.0           
[109] R6_2.5.1                      BiocIO_1.4.0                 
[111] bookdown_0.24                 promises_1.2.0.1             
[113] gridExtra_2.3                 vipor_0.4.5                  
[115] codetools_0.2-18              assertthat_0.2.1             
[117] rjson_0.2.20                  withr_2.4.2                  
[119] GenomicAlignments_1.30.0      Rsamtools_2.10.0             
[121] GenomeInfoDbData_1.2.7        parallel_4.1.1               
[123] hms_1.1.1                     grid_4.1.1                   
[125] beachmat_2.10.0               rmarkdown_2.11               
[127] DelayedMatrixStats_1.16.0     Rtsne_0.15                   
[129] shiny_1.7.1                   ggbeeswarm_0.6.0             
[131] restfulr_0.0.13              
```
</div>
